@@ -155,7 +155,7 @@ if ($do==1) {
          "CGI_script\',arguments=\'$cygloc\\script\\fullautoapi_fastcgi.pl ".
          "-e\',maxInstances=\'4\',idleTimeout=\'300\',activityTimeout=\'30\',".
          "requestTimeout=\90\',instanceMaxRequests=\'1000\',protocol=".
-         "\'NamedPipe\',flushNamedPipe=\'False\']" /commit:apphost",
+         "\'NamedPipe\',flushNamedPipe=\'False\']\" /commit:apphost",
          '__display__');
       ($stdout,$stderr)=$handle->cmd("appcmd set config -section:".
          "\"FullAutoAPI\" -section:system.webServer/handlers /+\"[name=".
